@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/api.lisp,v 1.59 2005/06/26 22:01:16 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/api.lisp,v 1.61 2005/12/06 16:50:50 edi Exp $
 
 ;;; The external API for creating and using scanners.
 
@@ -205,19 +205,22 @@ NIL the function is allowed to destructively modify its first argument
                    :single-line single-line-mode
                    :return :index))
 
-(defgeneric scan (regex target-string &key start end)
+(defgeneric scan (regex target-string &key start end real-start-pos)
   (:documentation "Searches TARGET-STRING from START to END and tries
-to match REGEX. On success returns four values - the start of the
+to match REGEX.  On success returns four values - the start of the
 match, the end of the match, and two arrays denoting the beginnings
-and ends of register matches. On failure returns NIL. REGEX can be a
+and ends of register matches.  On failure returns NIL.  REGEX can be a
 string which will be parsed according to Perl syntax, a parse tree, or
-a pre-compiled scanner created by CREATE-SCANNER. TARGET-STRING will
-be coerced to a simple string if it isn't one already."))
+a pre-compiled scanner created by CREATE-SCANNER.  TARGET-STRING will
+be coerced to a simple string if it isn't one already.  The
+REAL-START-POS parameter should be ignored - it exists only for
+internal purposes."))
 
 #-:use-acl-regexp2-engine
 (defmethod scan ((regex-string string) target-string
                                        &key (start 0)
-                                            (end (length target-string)))
+                                            (end (length target-string))
+                                            ((:real-start-pos *real-start-pos*) nil))
   (declare #.*standard-optimize-settings*)
   ;; note that the scanners are optimized for simple strings so we
   ;; have to coerce TARGET-STRING into one if it isn't already
@@ -228,7 +231,8 @@ be coerced to a simple string if it isn't one already."))
 #-:use-acl-regexp2-engine
 (defmethod scan ((scanner function) target-string
                                     &key (start 0)
-                                         (end (length target-string)))
+                                         (end (length target-string))
+                                         ((:real-start-pos *real-start-pos*) nil))
   (declare #.*standard-optimize-settings*)
   (funcall scanner
            (maybe-coerce-to-simple-string target-string)
@@ -237,7 +241,8 @@ be coerced to a simple string if it isn't one already."))
 #-:use-acl-regexp2-engine
 (defmethod scan ((parse-tree t) target-string
                                 &key (start 0)
-                                     (end (length target-string)))
+                                     (end (length target-string))
+                                     ((:real-start-pos *real-start-pos*) nil))
   (declare #.*standard-optimize-settings*)
   (funcall (create-scanner parse-tree)
            (maybe-coerce-to-simple-string target-string)
@@ -249,7 +254,8 @@ be coerced to a simple string if it isn't one already."))
 #+:use-acl-regexp2-engine
 (defmethod scan ((parse-tree t) target-string
                                 &key (start 0)
-                                     (end (length target-string)))
+                                     (end (length target-string))
+                                     ((:real-start-pos *real-start-pos*) nil))
   (when (< end start)
     (return-from scan nil))
   (let ((results (multiple-value-list (excl:match-re parse-tree target-string
@@ -371,7 +377,6 @@ declarations."
       ;; the NIL BLOCK to enable exits via (RETURN ...)
       `(block nil
         (let* ((,%start (or ,start 0))
-               (*real-start-pos* ,%start)
                (,%end (or ,end (length ,target-string)))
                ,@(unless (constantp regex env)
                    ;; leave constant regular expressions as they are -
@@ -397,7 +402,8 @@ declarations."
                     (,match-start ,match-end ,reg-starts ,reg-ends)
                   (scan ,(cond ((constantp regex env) regex)
                                (t scanner))
-                        ,target-string :start ,%start :end ,%end)
+                        ,target-string :start ,%start :end ,%end
+                                       :real-start-pos ,%start)
                 ;; declare the variables to be IGNORABLE to prevent the
                 ;; compiler from issuing warnings
                 (declare
@@ -1067,14 +1073,14 @@ scanner, a case-insensitive scanner is used."
                                              (not (functionp ,regex)))))
               (,%packages (or ,packages
                               (list-all-packages))))
-        (with-package-iterator (,next ,%packages :external :internal)
-          (loop
-            (multiple-value-bind (,morep symbol)
-                (,next)
-              (unless ,morep
-                (return ,return-form))
-              (when (scan ,scanner (symbol-name symbol))
-                ,@body))))))))
+         (with-package-iterator (,next ,%packages :external :internal :inherited)
+           (loop
+             (multiple-value-bind (,morep symbol)
+                 (,next)
+               (unless ,morep
+                 (return ,return-form))
+               (when (scan ,scanner (symbol-name symbol))
+                 ,@body))))))))
 
 ;;; The following two functions were provided by Karsten Poeck
 
