@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-USER; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/packages.lisp,v 1.17 2004/09/30 09:58:42 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/packages.lisp,v 1.19 2005/04/01 21:29:10 edi Exp $
 
-;;; Copyright (c) 2002-2004, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2002-2005, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -59,7 +59,9 @@
            #:ppcre-syntax-error-string
            #:ppcre-syntax-error-pos
            #:register-groups-bind
-           #:do-register-groups))
+           #:do-register-groups
+           #:*standard-optimize-settings*
+           #:*special-optimize-settings*))
 
 #+:cormanlisp
 (defpackage "CL-PPCRE"
@@ -90,7 +92,9 @@
            "PPCRE-SYNTAX-ERROR-STRING"
            "PPCRE-SYNTAX-ERROR-POS"
            "REGISTER-GROUPS-BIND"
-           "DO-REGISTER-GROUPS"))
+           "DO-REGISTER-GROUPS"
+           "*STANDARD-OPTIMIZE-SETTINGS*"
+           "*SPECIAL-OPTIMIZE-SETTINGS*"))
 
 #-:cormanlisp
 (defpackage #:cl-ppcre-test
