@@ -1,11 +1,11 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/regex-class.lisp,v 1.22 2005/03/07 22:02:53 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/regex-class.lisp,v 1.26 2005/06/10 10:23:42 edi Exp $
 
 ;;; This file defines the REGEX class and some utility methods for
 ;;; this class. REGEX objects are used to represent the (transformed)
 ;;; parse trees internally
 
-;;; Copyright (c) 2002-2004, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2002-2005, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -37,12 +37,7 @@
 ;; definitions aren't seen by the typep calls later in the file.
 (eval-when (:compile-toplevel :load-toplevel :execute)
   (locally
-    (declare (optimize speed
-                       (safety 0)
-                       (space 0)
-                       (debug 1)
-                       (compilation-speed 0)
-                       #+:lispworks (hcl:fixnum-safety 0)))
+    (declare #.*standard-optimize-settings*)
     (defclass regex ()
          ()
       (:documentation "The REGEX base class. All other classes inherit
@@ -257,12 +252,7 @@ defined by the user."))
       (:documentation "VOID objects represent empty regular expressions."))))
 
 (defmethod initialize-instance :after ((char-class char-class) &rest init-args)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Make large hash tables smaller, if possible."
   (let ((hash (getf init-args :hash)))
     (when (and hash
@@ -275,18 +265,11 @@ defined by the user."))
             (slot-value char-class 'invertedp)
               (not (slot-value char-class 'invertedp))))))
 
-(declaim (ftype (function (t) simple-string) str))
-
 ;;; The following four methods allow a VOID object to behave like a
 ;;; zero-length STR object (only readers needed)
 
 (defmethod initialize-instance :after ((str str) &rest init-args)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (declare (ignore init-args))
   "Automatically computes the length of a STR after initialization."
   (let ((str-slot (slot-value str 'str)))
@@ -295,48 +278,23 @@ defined by the user."))
   (setf (len str) (length (str str))))
 
 (defmethod len ((void void))
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   0)
 
 (defmethod str ((void void))
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "")
 
 (defmethod skip ((void void))
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   nil)
 
 (defmethod start-of-end-string-p ((void void))
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   nil)
 
 (defgeneric case-mode (regex old-case-mode)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (:documentation "Utility function used by the optimizer (see GATHER-STRINGS).
 Returns a keyword denoting the case-(in)sensitivity of a STR or its
 second argument if the STR has length 0. Returns NIL for REGEX objects
@@ -355,12 +313,7 @@ which are not of type STR."))
   nil)
 
 (defgeneric copy-regex (regex)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (:documentation "Implements a deep copy of a REGEX object."))
 
 (defmethod copy-regex ((anchor anchor))
@@ -461,12 +414,7 @@ which are not of type STR."))
 ;;; and therefore we stop REGISTER removal once we see an ALTERNATION.
 
 (defgeneric remove-registers (regex)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (:documentation "Returns a deep copy of a REGEX (see COPY-REGEX) and
 optionally removes embedded REGISTER objects if possible and if the
 special variable REMOVE-REGISTERS-P is true."))
@@ -535,12 +483,7 @@ special variable REMOVE-REGISTERS-P is true."))
                  :elements (mapcar #'remove-registers (elements seq))))
 
 (defgeneric everythingp (regex)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (:documentation "Returns an EVERYTHING object if REGEX is equivalent
 to this object, otherwise NIL. So, \"(.){1}\" would return true
 (i.e. the object corresponding to \".\", for example."))
@@ -587,12 +530,7 @@ to this object, otherwise NIL. So, \"(.){1}\" would return true
   nil)
 
 (defgeneric regex-length (regex)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (:documentation "Return the length of REGEX if it is fixed, NIL otherwise."))
 
 (defmethod regex-length ((seq seq))
@@ -630,7 +568,7 @@ to this object, otherwise NIL. So, \"(.){1}\" would return true
                (maximum maximum))
       repetition
     (if (and len
-             (eq minimum maximum))
+             (eql minimum maximum))
       (* minimum len)
       nil)))
 
@@ -663,12 +601,7 @@ to this object, otherwise NIL. So, \"(.){1}\" would return true
   0)
 
 (defgeneric regex-min-length (regex)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (:documentation "Returns the minimal length of REGEX."))
 
 (defmethod regex-min-length ((seq seq))
@@ -719,12 +652,7 @@ to this object, otherwise NIL. So, \"(.){1}\" would return true
   0)
 
 (defgeneric compute-offsets (regex start-pos)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (:documentation "Returns the offset the following regex would have
 relative to START-POS or NIL if we can't compute it. Sets the OFFSET
 slot of REGEX to START-POS if REGEX is a STR. May also affect OFFSET
