@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/scanner.lisp,v 1.25 2005/04/01 21:29:10 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/scanner.lisp,v 1.26 2005/07/19 23:18:15 edi Exp $
 
 ;;; Here the scanner for the actual regex as well as utility scanners
 ;;; for the constant start and end strings are created.
@@ -94,8 +94,9 @@ instead. (BMH matchers are faster but need much more space.)"
   (let ((char-compare (if case-insensitive-p 'char-equal 'char=)))
     `(lambda (start-pos)
       (declare (type fixnum start-pos))
-      (loop for i of-type fixnum from start-pos below *end-pos*
-            thereis (and (,char-compare (schar *string* i) chr) i)))))
+      (and (not (minusp start-pos))
+           (loop for i of-type fixnum from start-pos below *end-pos*
+                 thereis (and (,char-compare (schar *string* i) chr) i))))))
 
 (defun create-char-searcher (chr case-insensitive-p)
   (declare #.*standard-optimize-settings*)
