@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/util.lisp,v 1.30 2005/04/01 21:29:10 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/util.lisp,v 1.32 2005/08/23 10:32:30 edi Exp $
 
 ;;; Utility functions and constants dealing with the hash-tables
 ;;; we use to encode character classes
@@ -35,6 +35,10 @@
 
 (in-package #:cl-ppcre)
 
+#+:lispworks
+(import 'lw:with-unique-names)
+
+#-:lispworks
 (defmacro with-unique-names ((&rest bindings) &body body)
   "Syntax: WITH-UNIQUE-NAMES ( { var | (var x) }* ) declaration* form*
 
@@ -65,6 +69,12 @@ are discarded \(that is, the body is an implicit PROGN)."
                  bindings)
          ,@body))
 
+#+:lispworks
+(eval-when (:compile-toplevel :load-toplevel :execute)
+  (setf (macro-function 'with-rebinding)
+          (macro-function 'lw:rebinding)))
+
+#-:lispworks
 (defmacro with-rebinding (bindings &body body)
   "WITH-REBINDING ( { var | (var prefix) }* ) form*
 
@@ -94,10 +104,10 @@ are discarded \(that is, the body is an implicit PROGN)."
 
 (eval-when (:compile-toplevel :execute :load-toplevel)
   (defvar *regex-char-code-limit* char-code-limit
-    "The upper exclusive bound on the char-codes of characters
-which can occur in character classes.
-Change this value BEFORE creating scanners if you don't need
-the full Unicode support of LW, ACL, or CLISP.")
+    "The upper exclusive bound on the char-codes of characters which
+can occur in character classes.  Change this value BEFORE creating
+scanners if you don't need the Unicode support of implementations like
+AllegroCL, CLISP, LispWorks, or SBCL.")
   (declaim (type fixnum *regex-char-code-limit*))
   
   (defun make-char-hash (test)
